/**
 * Ephoto Dam Addon for Drupal 9
 *
 * @base EPHOTO DAM FIELD
 * @author EINDEN
 */

(function ($) {
  Drupal.ephotoDamField = {
    /**
     * EPHOTO ID of Drupal Addon
     */		
    CLIENT_ID: 'CaCvqS5H',
    
    /**
     * Settings
     */    
    settings: drupalSettings.ephotoDamField,

    /**
     * Current authid
     */     
    authid: null,

    /**
     * Ephoto Dam instance
     */		
    ephoto: null,
    
    /**
     * Ephoto Dam Server connected
     */		
    connected: false, 
    
    /**
     * Current selected field
     */
    fieldSelected : null,

    /**
     * Enable version support
     */    
    enableVersionSupport: function(el) {
      if(el.checked) {
        $('.ephoto-dam-field-version-field').removeClass('ephoto-dam-field-hidden');
        $('.ephoto-dam-field-version-prefix').removeClass('ephoto-dam-field-hidden');
        
        $('.ephoto-dam-field-versions-button').removeClass('ephoto-dam-field-hidden');
        $('.ephoto-dam-field-file-button').addClass('ephoto-dam-field-hidden');
      }

      else {
        $('.ephoto-dam-field-version-field').addClass('ephoto-dam-field-hidden');
        $('.ephoto-dam-field-version-prefix').addClass('ephoto-dam-field-hidden');        
        
        $('.ephoto-dam-field-versions-button').addClass('ephoto-dam-field-hidden');
        $('.ephoto-dam-field-file-button').removeClass('ephoto-dam-field-hidden');
      }
    },

    /**
     * Load Ephoto Dam Api
     */
    load: function() {
        if (this.settings && this.settings.server_url) {
            $.getScript(this.settings.server_url + '/api/apiJS.js', this.init.bind(this));
        }
    },
    
    /**
     * Init Ephoto Dam Api
     */    
    init: function() {
        var self = this;

        if (!ePhoto) {
            console.log(Drupal.t('Error loading the Ephoto Dam API'));
            return;
        }

        this.authid = $.cookie('drupal_ephoto_dam_authid');

        this.ephoto = new ePhoto({
            'server': this.settings.server_url,
            'authID': this.authid,
            'client': this.CLIENT_ID
        });

        this.ephoto.connect();

        this.ephoto.File.callOnFileReceived(this.getUrl.bind(this));

        this.ephoto.File.enableDCore();

        this.ephoto.File.setMode('manual');

        this.ephoto.callOnConnect(function() {
            let version = self.ephoto.getVersion().split('.');

            // Requires API version 6.0 (Ephoto Dam 4.0)
            if (version.length !==3 || version[0] < 6) {
                alert(Drupal.t('The version of Ephoto Dam is not compatible with this function'));
                return;
            }

            self.authid = self.ephoto.getAuthID();

            $.cookie('drupal_ephoto_dam_authid', self.authid, { path:'/' });

            self.connected = true;
        });
    },

    /**
     *
     */
    selectVersions: function() {
        let versions = this._getFieldValues();

        // this.ephoto.File.setButtons !!
        //this.ephoto.File.get();
    },

    /**
     * Select file
     * 
     * @param {number} Field index
     */    
    selectFile: function(delta) {
        this.fieldSelected = this._getFieldValues()[delta];

        if (!this.fieldSelected) {
            console.log('Field selection error');
            return;
        }

        let size = this.fieldSelected.size.toString().split('x').map(function(val) {
            val = val === '' || isNaN(val) ? 0 : parseInt(val, 10);
            return (val > 1600) ? 1600 : ((val <= 0) ? '' : val);

        }).join('x');

        if (size === '' || size === 0) return;

        this.ephoto.File.setButtons( this.ephoto.IMAGE_FILES, [ {
            'definition': 'custom',
            'size': size,
            'dpi': 72,
            'format': 'jpg',
            'notEnlarge': true
        } ] );        

        this.ephoto.File.get();
    },

    /**
     * Get URL of selected file
     */    
    getUrl: function(empty_value, dcore) {
        if (dcore === 'fileDoesNotExist') {
            console.log('File does not exist');
            return;
        }

        var self = this;
        var version_support = this.settings.version_support === '1';

        if (!this.fieldSelected) {
            console.log('Field selected missing');
            return;
        }

        this.ephoto.File.store(function(url) {
            self.fieldSelected.input.val(url);
            self.fieldSelected = null;
        });  
    },

    /**
     * Get all field values
     */
    _getFieldValues: function() {
        var fields = [];
        var sizes = $('.ephoto-dam-field-imagesize-field').toArray();
        var inputs = $('.ephoto-dam-field-url-field').toArray();

        $('.ephoto-dam-field-version-field').map(function(index, el) {
            fields.push({
                'name' : $(el).val(),
                'size' : $(sizes[index]).val(),
                'input' : $(inputs[index])
            });
        });

        return fields;
    },     
  }

})(jQuery);

Drupal.ephotoDamField.load();
